<?php
if (!defined('ABSPATH')) {
    exit;
}

// 管理メニューの追加
function horoscope_admin_menu() {
    add_menu_page(
        '運勢予報管理', 
        '運勢予報', 
        'manage_options', 
        'horoscope-admin', 
        'horoscope_admin_page', 
        'dashicons-calendar-alt', 
        6
    );

    // サブメニューの追加
    add_submenu_page(
        'horoscope-admin',
        'フォント設定',
        'フォント設定',
        'manage_options',
        'horoscope-font-settings',
        'horoscope_font_settings_page'
    );

    add_submenu_page(
        'horoscope-admin',
        '運勢データのエクスポート',
        'データエクスポート',
        'manage_options',
        'horoscope-export',
        'horoscope_export_page'
    );
}
add_action('admin_menu', 'horoscope_admin_menu');

// 管理ページの表示
function horoscope_admin_page() {
    $zodiac_signs = array(
        'aries' => '牡羊座', 'taurus' => '牡牛座', 'gemini' => '双子座', 'cancer' => '蟹座',
        'leo' => '獅子座', 'virgo' => '乙女座', 'libra' => '天秤座', 'scorpio' => '蠍座',
        'sagittarius' => '射手座', 'capricorn' => '山羊座', 'aquarius' => '水瓶座', 'pisces' => '魚座'
    );

    $start_date = current_time('Y-m-d');
    $end_date = date('Y-m-d', strtotime($start_date . ' +10 days'));

    if (isset($_POST['save_horoscopes'])) {
        save_horoscopes($zodiac_signs, $start_date, $end_date);
    }
    ?>
    <div class="wrap">
        <h1>運勢予報管理</h1>
        <form method="post" action="">
            <div class="horoscope-table-container">
                <table class="widefat">
                    <thead>
                        <tr>
                            <th>星座</th>
                            <?php
                            for ($date = $start_date; $date <= $end_date; $date = date('Y-m-d', strtotime($date . ' +1 day'))) {
                                echo '<th>' . date('m/d', strtotime($date)) . '</th>';
                            }
                            ?>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($zodiac_signs as $sign => $name) : ?>
                            <tr>
                                <td><?php echo esc_html($name); ?></td>
                                <?php
                                for ($date = $start_date; $date <= $end_date; $date = date('Y-m-d', strtotime($date . ' +1 day'))) {
                                    $horoscope = get_horoscope($sign, $date);
                                    ?>
                                    <td>
                                        <textarea name="horoscope[<?php echo $sign; ?>][<?php echo $date; ?>]" 
                                                  rows="4" 
                                                  style="width: 100%;"><?php echo esc_textarea($horoscope); ?></textarea>
                                    </td>
                                    <?php
                                }
                                ?>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
            <?php wp_nonce_field('save_horoscopes', 'horoscope_nonce'); ?>
            <p class="submit">
                <input type="submit" name="save_horoscopes" class="button-primary" value="運勢を保存">
            </p>
        </form>
    </div>
    <?php
}

// 運勢データの保存
function save_horoscopes($zodiac_signs, $start_date, $end_date) {
    if (!isset($_POST['horoscope_nonce']) || !wp_verify_nonce($_POST['horoscope_nonce'], 'save_horoscopes')) {
        wp_die('セキュリティチェックに失敗しました。');
    }

    foreach ($zodiac_signs as $sign => $name) {
        for ($date = $start_date; $date <= $end_date; $date = date('Y-m-d', strtotime($date . ' +1 day'))) {
            if (!isset($_POST['horoscope'][$sign][$date])) {
                continue;
            }

            $content = sanitize_textarea_field($_POST['horoscope'][$sign][$date]);
            $post_id = get_horoscope_post_id($sign, $date);

            if ($post_id) {
                wp_update_post(array(
                    'ID' => $post_id,
                    'post_content' => $content
                ));
            } else {
                wp_insert_post(array(
                    'post_type' => 'horoscope',
                    'post_title' => $name . ' ' . $date,
                    'post_content' => $content,
                    'post_status' => 'publish',
                    'meta_input' => array(
                        'zodiac_sign' => $sign,
                        'horoscope_date' => $date
                    )
                ));
            }
        }
    }
    
    echo '<div class="updated"><p>運勢を保存しました。</p></div>';
}

// 運勢データの取得
function get_horoscope($sign, $date) {
    $args = array(
        'post_type' => 'horoscope',
        'posts_per_page' => 1,
        'meta_query' => array(
            array('key' => 'zodiac_sign', 'value' => $sign),
            array('key' => 'horoscope_date', 'value' => $date)
        )
    );
    $query = new WP_Query($args);
    if ($query->have_posts()) {
        $query->the_post();
        $content = get_the_content();
        wp_reset_postdata();
        return $content;
    }
    return '';
}

// 運勢投稿IDの取得
function get_horoscope_post_id($sign, $date) {
    $args = array(
        'post_type' => 'horoscope',
        'posts_per_page' => 1,
        'meta_query' => array(
            array('key' => 'zodiac_sign', 'value' => $sign),
            array('key' => 'horoscope_date', 'value' => $date)
        )
    );
    $query = new WP_Query($args);
    if ($query->have_posts()) {
        $query->the_post();
        $id = get_the_ID();
        wp_reset_postdata();
        return $id;
    }
    return 0;
}
?>