<?php
if (!defined('ABSPATH')) {
    exit;
}

// エクスポートページの表示
function horoscope_export_page() {
    if (isset($_POST['export_horoscope']) && check_admin_referer('horoscope_export', 'horoscope_export_nonce')) {
        export_horoscope_to_csv();
    }
    ?>
    <div class="wrap">
        <h1>運勢データのエクスポート</h1>
        <form method="post" action="">
            <?php wp_nonce_field('horoscope_export', 'horoscope_export_nonce'); ?>
            <p>削除される前の過去10日分の運勢データをダウンロードします。</p>
            <p>このデータはAI学習用に保存されます。</p>
            <input type="submit" name="export_horoscope" class="button-primary" value="CSVをダウンロード">
        </form>
    </div>
    <?php
}

function export_horoscope_to_csv() {
    // 出力バッファをクリア
    ob_clean();
    
    $zodiac_signs = array(
        'aries' => '牡羊座', 'taurus' => '牡牛座', 'gemini' => '双子座', 'cancer' => '蟹座',
        'leo' => '獅子座', 'virgo' => '乙女座', 'libra' => '天秤座', 'scorpio' => '蠍座',
        'sagittarius' => '射手座', 'capricorn' => '山羊座', 'aquarius' => '水瓶座', 'pisces' => '魚座'
    );

    // 日付範囲の設定
    $today = current_time('Y-m-d');
    $ten_days_ago = date('Y-m-d', strtotime('-10 days', strtotime($today)));

    // クエリの設定
    $args = array(
        'post_type' => 'horoscope',
        'posts_per_page' => -1,
        'meta_query' => array(
            array(
                'key' => 'horoscope_date',
                'value' => array($ten_days_ago, $today),
                'type' => 'DATE',
                'compare' => 'BETWEEN'
            )
        ),
        'orderby' => 'meta_value',
        'meta_key' => 'horoscope_date',
        'order' => 'ASC'
    );

    $query = new WP_Query($args);
    $posts = $query->posts;

    // ヘッダーの設定
    header('Content-Type: text/csv; charset=utf-8');
    header('Content-Disposition: attachment; filename=horoscope-data-' . $today . '.csv');
    header('Pragma: no-cache');
    header('Expires: 0');

    // ファイルハンドルを開く
    $output = fopen('php://output', 'w');

    // BOMを出力
    fputs($output, "\xEF\xBB\xBF");

    // ヘッダー行を書き込む
    fputcsv($output, array('日付', '星座', '運勢メッセージ'));

    // データを書き込む
    if ($posts) {
        foreach ($posts as $post) {
            $date = get_post_meta($post->ID, 'horoscope_date', true);
            $sign = get_post_meta($post->ID, 'zodiac_sign', true);
            
            if (isset($zodiac_signs[$sign])) {
                fputcsv($output, array(
                    $date,
                    $zodiac_signs[$sign],
                    strip_tags($post->post_content)
                ));
            }
        }
    }

    // ファイルハンドルを閉じる
    fclose($output);
    exit;
}