<?php
if (!defined('ABSPATH')) {
    exit;
}

// フォント設定の初期化
function horoscope_font_settings_init() {
    register_setting('horoscope_options', 'horoscope_font_settings');

    add_settings_section(
        'horoscope_font_section',
        'フォント設定',
        'horoscope_font_section_callback',
        'horoscope-settings'
    );

    add_settings_field(
        'horoscope_font',
        'フォントの選択',
        'horoscope_font_field_callback',
        'horoscope-settings',
        'horoscope_font_section'
    );
}
add_action('admin_init', 'horoscope_font_settings_init');

// フォント設定ページの表示
function horoscope_font_settings_page() {
    if (!current_user_can('manage_options')) {
        return;
    }
    ?>
    <div class="wrap">
        <h1><?php echo esc_html(get_admin_page_title()); ?></h1>
        <form action="options.php" method="post">
            <?php
            settings_fields('horoscope_options');
            do_settings_sections('horoscope-settings');
            submit_button('設定を保存');
            ?>
        </form>
    </div>
    <?php
}

// セクションの説明
function horoscope_font_section_callback() {
    echo '<p>運勢予報の表示に使用するフォントを選択してください。</p>';
}

// フォント選択フィールド
function horoscope_font_field_callback() {
    $options = get_option('horoscope_font_settings');
    $current_font = isset($options['font']) ? $options['font'] : 'noto-sans-jp';
    $fonts = array(
        'noto-sans-jp' => 'Noto Sans JP',
        'noto-serif-jp' => 'Noto Serif JP',
        'mplus-1' => 'M PLUS 1',
        'shippori-mincho' => 'しっぽり明朝'
    );
    ?>
    <select name="horoscope_font_settings[font]">
        <?php foreach ($fonts as $value => $label) : ?>
            <option value="<?php echo esc_attr($value); ?>" <?php selected($current_font, $value); ?>>
                <?php echo esc_html($label); ?>
            </option>
        <?php endforeach; ?>
    </select>
    <?php
}

// フロントエンド用フォントの読み込み
function enqueue_horoscope_font_styles() {
    $options = get_option('horoscope_font_settings');
    $selected_font = isset($options['font']) ? $options['font'] : 'noto-sans-jp';

    $font_urls = array(
        'noto-sans-jp' => 'https://fonts.googleapis.com/css2?family=Noto+Sans+JP:wght@400;500;700&display=swap',
        'noto-serif-jp' => 'https://fonts.googleapis.com/css2?family=Noto+Serif+JP:wght@400;500;700&display=swap',
        'mplus-1' => 'https://fonts.googleapis.com/css2?family=M+PLUS+1:wght@400;500;700&display=swap',
        'shippori-mincho' => 'https://fonts.googleapis.com/css2?family=Shippori+Mincho:wght@400;500;600&display=swap'
    );

    $font_families = array(
        'noto-sans-jp' => "'Noto Sans JP', sans-serif",
        'noto-serif-jp' => "'Noto Serif JP', serif",
        'mplus-1' => "'M PLUS 1', sans-serif",
        'shippori-mincho' => "'Shippori Mincho', serif"
    );

    wp_enqueue_style('horoscope-google-font', $font_urls[$selected_font], array(), null);
    
    $custom_css = "
        .horoscope-container,
        .horoscope-container h2,
        .zodiac-name,
        .horoscope-message {
            font-family: {$font_families[$selected_font]};
        }
    ";
    wp_add_inline_style('horoscope-style', $custom_css);
}
add_action('wp_enqueue_scripts', 'enqueue_horoscope_font_styles', 20);
?>